summaryrefslogtreecommitdiff
path: root/make_release.sh
diff options
context:
space:
mode:
Diffstat (limited to 'make_release.sh')
-rwxr-xr-xmake_release.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/make_release.sh b/make_release.sh
index 02affb0..bbb633d 100755
--- a/make_release.sh
+++ b/make_release.sh
@@ -2,7 +2,7 @@
# This script was adapted from fkooman: https://git.sr.ht/~fkooman/vpn-daemon/tree/main/item/make_release.sh. Thanks!
#
# Make a release of the version specified in internal/version/version.go and automatically release the artifacts
#
# Fail if error
@@ -11,7 +11,7 @@ set -e
echo "building $(git log -n 1 | head -n 1)"
BRANCH="main"
PROJECT_NAME=$(basename "${PWD}")
-PROJECT_VERSION=$(grep -o 'const Version = "[^"]*' internal/version/version.go | cut -d '"' -f 2)
+PROJECT_VERSION=$(grep -o 'const Version = "[^"]*' internal/commonver/commonver.go | cut -d '"' -f 2)
PRERELEASE=false
while [[ "$#" -gt 0 ]]; do
@@ -2,7 +2,7 @@
# This script was adapted from fkooman: https://git.sr.ht/~fkooman/vpn-daemon/tree/main/item/make_release.sh. Thanks!
#
-# Make a release of the version specified in internal/version/version.go and automatically release the artifacts
+# Make a release of the version specified in internal/commonver/commonver.go and automatically release the artifacts
#
# Fail if error